import java.awt.*;
import java.awt.event.*;

import org.lekan.graphics.GraphicsProgram;


/**
 * Here's an intro/review to using Java, and an intro to using the SGGraphics package.
 * 
 * Your task: build a simple drawing program that does, at the minimum, the following:
 *  (1) Buttons that lets you choose whether to draw an ellipse, a rectangle, a line, a rounded rectangle, or a quadratic curve
 *  (2) When the program first starts, the main canvas should display a nice welcoming message and/or graphics.
 *  (3) As soon as the user starts drawing, this welcome message should disappear
 *  (4) To draw, click and drag the mouse. The shape should display as you are dragging.
 *  (5) When released, the shape will stay on the screen.
 *  (6) A clear button will clear everything on the screen.
 * 
 * @author Vincent Wang
 * @version Last Updated: 6/21/11
 */
public class CoolDrawer extends GraphicsProgram {
	private static final String[] shapes = {"ellipse", "rectangle", "line", "roundRect", "quadCurve"};
	private int initX, initY, currShape = -1;
	private boolean aboutToDraw = false, debug = false;
	
	public static void main(String[] args) {
		new CoolDrawer();
	}
	
	/**
	 * Put any setup code here! */
	@Override
	public void setup() {
		addButton("Draw Rectangle", BorderLayout.NORTH);
		
		addButton("Draw Ellipse", BorderLayout.EAST);
		addButton("Draw Line", BorderLayout.EAST);
		addButton("Draw Rounded Rectangle", BorderLayout.WEST);
		addButton("Draw Quadratic Curve", BorderLayout.WEST);
		
		addButton("Clear Screen", BorderLayout.SOUTH);
		
		
		this.getFrame().setTitle("EPGYDraw!");
	}
	
	public void actionPerformed(ActionEvent e) {	/// what to do when a button is pressed
		super.actionPerformed(e);
		String name = e.getActionCommand();
		
		aboutToDraw = true;	/// use currShape to store which shape to draw
		if (name.equals("Draw Ellipse"))
			currShape = 0;
		else if (name.equals("Draw Rectangle"))
			currShape = 1;
		else if (name.equals("Draw Line"))
			currShape = 2;
		else if (name.equals("Draw Rounded Rectangle"))
			currShape = 3;
		else if (name.equals("Draw Quadratic Curve"))
			currShape = 4;
		else if (name.equals("Clear Screen")) {
			System.out.println("clear screen!");
			getFrame().clearGraphics();
		}
		else
			throw new IllegalStateException("Unknown button " + name);
	}
	
	public void mousePressed(MouseEvent e) {
		super.mousePressed(e);
		if (aboutToDraw) {		/// only get mouse position if button has been pressed
			initX = e.getX();
			initY = e.getY();
		}
	}
	
	public void mouseDragged(MouseEvent e) {
		super.mouseDragged(e);
		if (!aboutToDraw)	/// do nothing if no button has been pressed
			return;
		if (debug)
			System.out.println("Drawing a(n) " + shapes[currShape]);
		int newX = e.getX(), newY = e.getY();	/// get new mouse coordinates
		getFrame().clearGraphics();	/// clear screen to prevent trail of images
		
		switch(currShape) {	/// decide which shape to draw
			case 0 : 
				int midX = (initX + newX)/2, midY = (initY + newY)/2;
				int xRad = Math.abs((initX-newX)/2), yRad = Math.abs((initY-newY)/2);
				getFrame().drawEllipse(midX, midY, xRad, yRad); break;
			case 1 : case 3 :
				int startX = Math.min(initX, newX), startY = Math.min(initY, newY);
				int lenX = Math.abs(initX-newX), lenY = Math.abs(initY-newY);
				if (currShape == 1)
					getFrame().drawRect(startX, startY, lenX, lenY);
				else
					getFrame().drawRoundedRect(startX, startY, lenX, lenY, (int)(lenX*0.1), (int)(lenY*0.1)); break;
			case 2 : getFrame().drawLine(initX, initY, newX, newY); break;
			case 4 :
				int vertX = (initX + newX)/2, ctrlY = initY + 2*(newY - initY);
				getFrame().drawQuadCurve(initX, initY, vertX, ctrlY, newX, initY);
			/*	System.out.println("\n\nMouse @ (" + newX + " , " + newY + ")\n");
				System.out.println("Start point: (" + initX + " , " + initY + ")");
				System.out.println("Control point: (" + vertX + " , " + ctrlY + ")");
				System.out.println("End point: (" + newX + " , " + initY + ")"); */ break;
		}
	}
	
	/**
	 * Put your program run code here! Most of your code should be in here. */
	@Override
	public void run() {
		this.getFrame().drawText("Have lots of fun drawing shapes! :D", 10, 40);
	}
}
